@@ -51,7 +51,7 @@ public Q_SLOTS:
     void queueThumbnail(const QString&, const QImage&);
 
 protected:
-    void run();
+    void run() override;
 
 private:
     typedef QHash<QString, QImage> Cache;
